==> catalystcentersdk-2.3.7.9.3-py3-none-any.whl: catalystcentersdk/models/validators/v2_3_7_6_1/jsd_f486694f3da57b4921b7f2036a1b754.py <==
# -*- coding: utf-8 -*-
"""Cisco Catalyst Center UpdateAnycastGatewaysV1 data model.

Copyright (c) 2024 Cisco Systems.

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
"""



import json
from builtins import *

import fastjsonschema

from catalystcentersdk.exceptions import MalformedRequest


class JSONSchemaValidatorF486694F3Da57B4921B7F2036A1B754(object):
    """UpdateAnycastGatewaysV1 request schema definition."""
    def __init__(self):
        super(JSONSchemaValidatorF486694F3Da57B4921B7F2036A1B754, self).__init__()
        self._validator = fastjsonschema.compile(json.loads(
            '''{
                "$schema": "http://json-schema.org/draft-04/schema#",
                "items": {
                "properties": {
                "fabricId": {
                "type": "string"
                },
                "id": {
                "type": "string"
                },
                "ipPoolName": {
                "type": "string"
                },
                "isCriticalPool": {
                "type": "boolean"
                },
                "isGroupBasedPolicyEnforcementEnabled": {
                "type": "boolean"
                },
                "isIntraSubnetRoutingEnabled": {
                "type": "boolean"
                },
                "isIpDirectedBroadcast": {
                "type": "boolean"
                },
                "isLayer2FloodingEnabled": {
                "type": "boolean"
                },
                "isMultipleIpToMacAddresses": {
                "type": "boolean"
                },
                "isSupplicantBasedExtendedNodeOnboarding": {
                "type": "boolean"
                },
                "isWirelessPool": {
                "type": "boolean"
                },
                "poolType": {
                "enum": [
                "EXTENDED_NODE",
                "FABRIC_AP"
                ],
                "type": "string"
                },
                "securityGroupName": {
                "type": "string"
                },
                "tcpMssAdjustment": {
                "type": "integer"
                },
                "trafficType": {
                "enum": [
                "DATA",
                "VOICE"
                ],
                "type": "string"
                },
                "virtualNetworkName": {
                "type": "string"
                },
                "vlanId": {
                "type": "integer"
                },
                "vlanName": {
                "type": "string"
                }
                },
                "type": "object"
                },
                "type": "array"
                }'''.replace("\n" + ' ' * 16, '')
        ))

    def validate(self, request):
        try:
            self._validator(request)
        except fastjsonschema.exceptions.JsonSchemaException as e:
            raise MalformedRequest(
                '{} is invalid. Reason: {}'.format(request, e.message)
            )

==> catalystcentersdk-3.1.3.0.0-py3-none-any.whl: catalystcentersdk/models/validators/v3_1_3_0/jsd_f486694f3da57b4921b7f2036a1b754.py <==
# -*- coding: utf-8 -*-
"""Cisco DNA Center UpdateAnycastGateways data model.

Copyright (c) 2025 Cisco Systems.

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
"""

from __future__ import (
    absolute_import,
    division,
    print_function,
    unicode_literals,
)

import json
from builtins import *

import fastjsonschema

from catalystcentersdk.exceptions import MalformedRequest


class JSONSchemaValidatorF486694F3Da57B4921B7F2036A1B754(object):
    """UpdateAnycastGateways request schema definition."""

    def __init__(self):
        super(JSONSchemaValidatorF486694F3Da57B4921B7F2036A1B754, self).__init__()
        self._validator = fastjsonschema.compile(
            json.loads(
                """{
                "$schema": "http://json-schema.org/draft-04/schema#",
                "items": {
                "properties": {
                "fabricId": {
                "type": "string"
                },
                "id": {
                "type": "string"
                },
                "ipPoolName": {
                "type": "string"
                },
                "isCriticalPool": {
                "type": "boolean"
                },
                "isGroupBasedPolicyEnforcementEnabled": {
                "type": "boolean"
                },
                "isIntraSubnetRoutingEnabled": {
                "type": "boolean"
                },
                "isIpDirectedBroadcast": {
                "type": "boolean"
                },
                "isLayer2FloodingEnabled": {
                "type": "boolean"
                },
                "isMultipleIpToMacAddresses": {
                "type": "boolean"
                },
                "isResourceGuardEnabled": {
                "type": "boolean"
                },
                "isSupplicantBasedExtendedNodeOnboarding": {
                "type": "boolean"
                },
                "isWirelessFloodingEnabled": {
                "type": "boolean"
                },
                "isWirelessPool": {
                "type": "boolean"
                },
                "layer2FloodingAddress": {
                "type": "string"
                },
                "layer2FloodingAddressAssignment": {
                "enum": [
                "SHARED",
                "CUSTOM"
                ],
                "type": "string"
                },
                "poolType": {
                "enum": [
                "EXTENDED_NODE",
                "FABRIC_AP"
                ],
                "type": "string"
                },
                "securityGroupName": {
                "type": "string"
                },
                "tcpMssAdjustment": {
                "type": "integer"
                },
                "trafficType": {
                "enum": [
                "DATA",
                "VOICE"
                ],
                "type": "string"
                },
                "virtualNetworkName": {
                "type": "string"
                },
                "vlanId": {
                "type": "integer"
                },
                "vlanName": {
                "type": "string"
                }
                },
                "type": "object"
                },
                "type": "array"
                }""".replace(
                    "\n" + " " * 16, ""
                )
            )
        )

    def validate(self, request):
        try:
            self._validator(request)
        except fastjsonschema.exceptions.JsonSchemaException as e:
            raise MalformedRequest(
                "{} is invalid. Reason: {}".format(request, e.message)
            )
